Changelog
=========

`2.0.1 <https://github.com/NiaOrg/NiaPy/tree/2.0.1>`__ (2022-03-05)
-------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0...2.0.1>`__

**Implemented enhancements:**

-  Installation instructions for Arch Linux users
   `#373 <https://github.com/NiaOrg/NiaPy/issues/373>`__

**Closed issues:**

-  Whale Optimization Algorithm (WOA) and Sparrow Search Algorithm (SSA)
   implementation `#378 <https://github.com/NiaOrg/NiaPy/issues/378>`__
-  raise ValueError(‘Newlines are not allowed’)
   `#371 <https://github.com/NiaOrg/NiaPy/issues/371>`__
-  Logging not working if optimization type set to maximization
   `#367 <https://github.com/NiaOrg/NiaPy/issues/367>`__
-  ConalgTestCase related tests warnings
   `#364 <https://github.com/NiaOrg/NiaPy/issues/364>`__
-  Correct naming of Michalewicz functions
   `#361 <https://github.com/NiaOrg/NiaPy/issues/361>`__
-  Second stable release
   `#359 <https://github.com/NiaOrg/NiaPy/issues/359>`__

**Merged pull requests:**

-  docs: add firefly-cpp as a contributor for platform
   `#382 <https://github.com/NiaOrg/NiaPy/pull/382>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  docs: add carlosal1015 as a contributor for platform
   `#381 <https://github.com/NiaOrg/NiaPy/pull/381>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Modify convergence plotting
   `#380 <https://github.com/NiaOrg/NiaPy/pull/380>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Update Algorithms.md
   `#377 <https://github.com/NiaOrg/NiaPy/pull/377>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Add instructions for install from AUR
   `#374 <https://github.com/NiaOrg/NiaPy/pull/374>`__
   (`carlosal1015 <https://github.com/carlosal1015>`__)
-  Fix setup error `#372 <https://github.com/NiaOrg/NiaPy/pull/372>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Add nice badge for showing the total downloads of this package
   `#370 <https://github.com/NiaOrg/NiaPy/pull/370>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Add incremental testing to main workflow supported with cache
   `#369 <https://github.com/NiaOrg/NiaPy/pull/369>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Improve CI `#368 <https://github.com/NiaOrg/NiaPy/pull/368>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Add pytest-testmon to reduce the execution time of tests.
   `#366 <https://github.com/NiaOrg/NiaPy/pull/366>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fix clonalg implementation
   `#365 <https://github.com/NiaOrg/NiaPy/pull/365>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Refactor/fix michalewicz name
   `#363 <https://github.com/NiaOrg/NiaPy/pull/363>`__
   (`sisco0 <https://github.com/sisco0>`__)
-  Refactor/fix py typos
   `#362 <https://github.com/NiaOrg/NiaPy/pull/362>`__
   (`sisco0 <https://github.com/sisco0>`__)

.. _section-1:

`2.0.0 <https://github.com/NiaOrg/NiaPy/tree/2.0.0>`__ (2021-12-27)
-------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc18...2.0.0>`__

**Fixed bugs:**

-  BA implementation bug
   `#352 <https://github.com/NiaOrg/NiaPy/issues/352>`__

**Closed issues:**

-  Remove vim comments
   `#349 <https://github.com/NiaOrg/NiaPy/issues/349>`__
-  Infinity test problem is a duplicate of Csendes
   `#347 <https://github.com/NiaOrg/NiaPy/issues/347>`__
-  Add a citation.cff file
   `#346 <https://github.com/NiaOrg/NiaPy/issues/346>`__

**Merged pull requests:**

-  Do not package the tests
   `#358 <https://github.com/NiaOrg/NiaPy/pull/358>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Add badge for Fedora
   `#356 <https://github.com/NiaOrg/NiaPy/pull/356>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Fixed flake8 versions
   `#355 <https://github.com/NiaOrg/NiaPy/pull/355>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Maximization example corrected
   `#354 <https://github.com/NiaOrg/NiaPy/pull/354>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Fixed BA `#353 <https://github.com/NiaOrg/NiaPy/pull/353>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Loa algorithm `#351 <https://github.com/NiaOrg/NiaPy/pull/351>`__
   (`AljoM <https://github.com/AljoM>`__)
-  Removed vim comments
   `#350 <https://github.com/NiaOrg/NiaPy/pull/350>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Remove infinity test problem and add missing test problems to docs
   `#348 <https://github.com/NiaOrg/NiaPy/pull/348>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Fixed csendes function.
   `#345 <https://github.com/NiaOrg/NiaPy/pull/345>`__
   (`zStupan <https://github.com/zStupan>`__)

`2.0.0rc18 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc18>`__ (2021-08-18)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc17...2.0.0rc18>`__

**Closed issues:**

-  BA, CS and FA implementations are incorrect
   `#341 <https://github.com/NiaOrg/NiaPy/issues/341>`__
-  ModuleNotFoundError: No module named ‘NiaPy’
   `#339 <https://github.com/NiaOrg/NiaPy/issues/339>`__
-  Add Problems.md file
   `#332 <https://github.com/NiaOrg/NiaPy/issues/332>`__
-  Add an example/guide showing how to solve a real-world problem
   `#215 <https://github.com/NiaOrg/NiaPy/issues/215>`__

**Merged pull requests:**

-  docs: add andrazperson as a contributor for code
   `#343 <https://github.com/NiaOrg/NiaPy/pull/343>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Fix various algorithms
   `#342 <https://github.com/NiaOrg/NiaPy/pull/342>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Initial implementation of Clonal Selection Algorithm
   `#340 <https://github.com/NiaOrg/NiaPy/pull/340>`__
   (`andrazperson <https://github.com/andrazperson>`__)
-  docs: add firefly-cpp as a contributor for question, test
   `#337 <https://github.com/NiaOrg/NiaPy/pull/337>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Add Python 3.10 tag
   `#336 <https://github.com/NiaOrg/NiaPy/pull/336>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Update docs `#335 <https://github.com/NiaOrg/NiaPy/pull/335>`__
   (`zStupan <https://github.com/zStupan>`__)

`2.0.0rc17 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc17>`__ (2021-06-10)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc16...2.0.0rc17>`__

**Closed issues:**

-  Maximization doesn’t work
   `#328 <https://github.com/NiaOrg/NiaPy/issues/328>`__
-  Remove ThrowingTask and CountingTask
   `#317 <https://github.com/NiaOrg/NiaPy/issues/317>`__
-  Tasks are missing from the documentation.
   `#315 <https://github.com/NiaOrg/NiaPy/issues/315>`__
-  NiaPy fails to build with Python 3.10.0a7.
   `#308 <https://github.com/NiaOrg/NiaPy/issues/308>`__

**Merged pull requests:**

-  Edit Algorithms.md
   `#333 <https://github.com/NiaOrg/NiaPy/pull/333>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Rename BFOA `#331 <https://github.com/NiaOrg/NiaPy/pull/331>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Fixed Maximization
   `#329 <https://github.com/NiaOrg/NiaPy/pull/329>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Remove export directory
   `#327 <https://github.com/NiaOrg/NiaPy/pull/327>`__
   (`zStupan <https://github.com/zStupan>`__)
-  docs: add eltociear as a contributor
   `#326 <https://github.com/NiaOrg/NiaPy/pull/326>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Fix typo in jade.py
   `#324 <https://github.com/NiaOrg/NiaPy/pull/324>`__
   (`eltociear <https://github.com/eltociear>`__)
-  Remove ThrowingTask and CountingTask
   `#323 <https://github.com/NiaOrg/NiaPy/pull/323>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Benchmark refactor
   `#321 <https://github.com/NiaOrg/NiaPy/pull/321>`__
   (`zStupan <https://github.com/zStupan>`__)
-  docs: add lukapecnik as a contributor
   `#320 <https://github.com/NiaOrg/NiaPy/pull/320>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  docs: add zStupan as a contributor
   `#319 <https://github.com/NiaOrg/NiaPy/pull/319>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  docs: add hrnciar as a contributor
   `#318 <https://github.com/NiaOrg/NiaPy/pull/318>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Fix detection of two digit Python minor version
   `#316 <https://github.com/NiaOrg/NiaPy/pull/316>`__
   (`hrnciar <https://github.com/hrnciar>`__)

`2.0.0rc16 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc16>`__ (2021-05-26)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc15...2.0.0rc16>`__

**Implemented enhancements:**

-  Create a new release
   `#310 <https://github.com/NiaOrg/NiaPy/issues/310>`__

**Closed issues:**

-  niapy import fails for Python 3.6.x
   `#311 <https://github.com/NiaOrg/NiaPy/issues/311>`__

**Merged pull requests:**

-  Fixed import error.
   `#312 <https://github.com/NiaOrg/NiaPy/pull/312>`__
   (`zStupan <https://github.com/zStupan>`__)

`2.0.0rc15 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc15>`__ (2021-05-14)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc14...2.0.0rc15>`__

**Implemented enhancements:**

-  [JOSS] (Optional) Follow PEP-8 style guide in naming methods
   `#123 <https://github.com/NiaOrg/NiaPy/issues/123>`__

**Closed issues:**

-  Several TODOs in ca.py
   `#306 <https://github.com/NiaOrg/NiaPy/issues/306>`__
-  limit_repair method alters the input array
   `#294 <https://github.com/NiaOrg/NiaPy/issues/294>`__
-  CuckooSearch’s runIteration is incompatible with other algorithms
   runIteration `#281 <https://github.com/NiaOrg/NiaPy/issues/281>`__
-  ““” `#264 <https://github.com/NiaOrg/NiaPy/issues/264>`__

**Merged pull requests:**

-  Huge refactor `#309 <https://github.com/NiaOrg/NiaPy/pull/309>`__
   (`zStupan <https://github.com/zStupan>`__)
-  corrected reference URL for basic hs algorithm
   `#307 <https://github.com/NiaOrg/NiaPy/pull/307>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Switched to numpy.random.Generator for generating random numbers
   `#305 <https://github.com/NiaOrg/NiaPy/pull/305>`__
   (`zStupan <https://github.com/zStupan>`__)

`2.0.0rc14 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc14>`__ (2021-04-23)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc13...2.0.0rc14>`__

**Closed issues:**

-  scipy dependency
   `#303 <https://github.com/NiaOrg/NiaPy/issues/303>`__
-  Python 2.7 support
   `#301 <https://github.com/NiaOrg/NiaPy/issues/301>`__
-  Deprecation warnings
   `#297 <https://github.com/NiaOrg/NiaPy/issues/297>`__
-  Bug in Algorithm.runYield - runIteration executes nGEN - 1 times
   `#293 <https://github.com/NiaOrg/NiaPy/issues/293>`__
-  User defined function
   `#292 <https://github.com/NiaOrg/NiaPy/issues/292>`__

**Merged pull requests:**

-  Removed scipy dependency
   `#304 <https://github.com/NiaOrg/NiaPy/pull/304>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Dropped Python 2 Support
   `#302 <https://github.com/NiaOrg/NiaPy/pull/302>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Run method fix `#300 <https://github.com/NiaOrg/NiaPy/pull/300>`__
   (`zStupan <https://github.com/zStupan>`__)
-  Deprecation warnings and JADE fix
   `#299 <https://github.com/NiaOrg/NiaPy/pull/299>`__
   (`sisco0 <https://github.com/sisco0>`__)
-  some nitpicks `#298 <https://github.com/NiaOrg/NiaPy/pull/298>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  docs: add zStupan as a contributor
   `#296 <https://github.com/NiaOrg/NiaPy/pull/296>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Fixed bug in Algorithm.runYield
   `#295 <https://github.com/NiaOrg/NiaPy/pull/295>`__
   (`zStupan <https://github.com/zStupan>`__)
-  np.float is deprecated
   `#291 <https://github.com/NiaOrg/NiaPy/pull/291>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  BFOA quick fix `#290 <https://github.com/NiaOrg/NiaPy/pull/290>`__
   (`zStupan <https://github.com/zStupan>`__)

`2.0.0rc13 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc13>`__ (2021-03-10)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc12...2.0.0rc13>`__

**Closed issues:**

-  BFOA implementation
   `#288 <https://github.com/NiaOrg/NiaPy/issues/288>`__
-  BAT `#286 <https://github.com/NiaOrg/NiaPy/issues/286>`__
-  BAT Optimization Algorithm
   `#285 <https://github.com/NiaOrg/NiaPy/issues/285>`__
-  NiaPy conda dependecy problem
   `#284 <https://github.com/NiaOrg/NiaPy/issues/284>`__
-  xlwt is archived: consider dropping xlwt requirement?
   `#283 <https://github.com/NiaOrg/NiaPy/issues/283>`__
-  . `#263 <https://github.com/NiaOrg/NiaPy/issues/263>`__

**Merged pull requests:**

-  BFOA Fix `#289 <https://github.com/NiaOrg/NiaPy/pull/289>`__
   (`zStupan <https://github.com/zStupan>`__)
-  BFOA `#287 <https://github.com/NiaOrg/NiaPy/pull/287>`__
   (`zStupan <https://github.com/zStupan>`__)

`2.0.0rc12 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc12>`__ (2020-12-04)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc11...2.0.0rc12>`__

**Fixed bugs:**

-  Fixing issues related to tests at infinity benchmark and NPAging DE.
   `#267 <https://github.com/NiaOrg/NiaPy/pull/267>`__
   (`sisco0 <https://github.com/sisco0>`__)
-  Fix build description
   `#261 <https://github.com/NiaOrg/NiaPy/pull/261>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

**Closed issues:**

-  Fedora rpm build \| two tests are failing
   `#252 <https://github.com/NiaOrg/NiaPy/issues/252>`__

**Merged pull requests:**

-  Harris Hawks Optimization integration
   `#280 <https://github.com/NiaOrg/NiaPy/pull/280>`__
   (`sisco0 <https://github.com/sisco0>`__)
-  Fixed some LaTeX formulas
   `#279 <https://github.com/NiaOrg/NiaPy/pull/279>`__
   (`sisco0 <https://github.com/sisco0>`__)
-  Implementation of PLBA algorithm
   `#278 <https://github.com/NiaOrg/NiaPy/pull/278>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  several TODOs removed
   `#277 <https://github.com/NiaOrg/NiaPy/pull/277>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  tests for RS algorithm
   `#276 <https://github.com/NiaOrg/NiaPy/pull/276>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  corrections in table
   `#275 <https://github.com/NiaOrg/NiaPy/pull/275>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Exception handling & Random Search implementation
   `#274 <https://github.com/NiaOrg/NiaPy/pull/274>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Table of implemented algorithms added
   `#273 <https://github.com/NiaOrg/NiaPy/pull/273>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  removing TabuSearch - immature version
   `#272 <https://github.com/NiaOrg/NiaPy/pull/272>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Update README.md `#271 <https://github.com/NiaOrg/NiaPy/pull/271>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  LaTeX codes `#270 <https://github.com/NiaOrg/NiaPy/pull/270>`__
   (`sisco0 <https://github.com/sisco0>`__)
-  Update issue templates
   `#269 <https://github.com/NiaOrg/NiaPy/pull/269>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  docs: add sisco0 as a contributor
   `#268 <https://github.com/NiaOrg/NiaPy/pull/268>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  reference added, small fixes
   `#265 <https://github.com/NiaOrg/NiaPy/pull/265>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Fixes `#262 <https://github.com/NiaOrg/NiaPy/pull/262>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)

`2.0.0rc11 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc11>`__ (2020-07-19)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc10...2.0.0rc11>`__

**Implemented enhancements:**

-  Add workflow for publish to anaconda, setup.py fixes
   `#259 <https://github.com/NiaOrg/NiaPy/pull/259>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fix runner exports
   `#254 <https://github.com/NiaOrg/NiaPy/pull/254>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Add python 3.8 `#250 <https://github.com/NiaOrg/NiaPy/pull/250>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

**Fixed bugs:**

-  OptimizationType.MAXIMIZATION does not work with GWO
   `#246 <https://github.com/NiaOrg/NiaPy/issues/246>`__
-  Possible issue with unit test
   `#241 <https://github.com/NiaOrg/NiaPy/issues/241>`__
-  GWO TypeError: unsupported operand type(s)
   `#218 <https://github.com/NiaOrg/NiaPy/issues/218>`__
-  Fix algorithm utility to work with python2 and add tests
   `#239 <https://github.com/NiaOrg/NiaPy/pull/239>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

**Closed issues:**

-  No module named ‘NiaPy.task’
   `#243 <https://github.com/NiaOrg/NiaPy/issues/243>`__
-  Example run.py not working
   `#238 <https://github.com/NiaOrg/NiaPy/issues/238>`__
-  Algorithms checklist
   `#188 <https://github.com/NiaOrg/NiaPy/issues/188>`__

**Merged pull requests:**

-  Update versionbump
   `#260 <https://github.com/NiaOrg/NiaPy/pull/260>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Documentation update
   `#258 <https://github.com/NiaOrg/NiaPy/pull/258>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Update Sphinx theme, update outdated stuff
   `#257 <https://github.com/NiaOrg/NiaPy/pull/257>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Documentation update
   `#256 <https://github.com/NiaOrg/NiaPy/pull/256>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  updated README file
   `#255 <https://github.com/NiaOrg/NiaPy/pull/255>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Installation instructions for Fedora users
   `#253 <https://github.com/NiaOrg/NiaPy/pull/253>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  docs: add timzatko as a contributor
   `#251 <https://github.com/NiaOrg/NiaPy/pull/251>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Fix GWO maximization
   `#249 <https://github.com/NiaOrg/NiaPy/pull/249>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  update getting started documentation
   `#248 <https://github.com/NiaOrg/NiaPy/pull/248>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  docs: add brett18618 as a contributor
   `#242 <https://github.com/NiaOrg/NiaPy/pull/242>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Fix HSABA, SABA, ABA and fixes for examples
   `#240 <https://github.com/NiaOrg/NiaPy/pull/240>`__
   (`kb2623 <https://github.com/kb2623>`__)

`2.0.0rc10 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc10>`__ (2019-11-12)
---------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc9...2.0.0rc10>`__

**Implemented enhancements:**

-  PSO binary functionality
   `#187 <https://github.com/NiaOrg/NiaPy/issues/187>`__
-  Development `#233 <https://github.com/NiaOrg/NiaPy/pull/233>`__
   (`kb2623 <https://github.com/kb2623>`__)

**Fixed bugs:**

-  FSS implementation
   `#186 <https://github.com/NiaOrg/NiaPy/issues/186>`__
-  FPA implementation
   `#185 <https://github.com/NiaOrg/NiaPy/issues/185>`__

`2.0.0rc9 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc9>`__ (2019-11-11)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc8...2.0.0rc9>`__

**Merged pull requests:**

-  Fix publish workflow
   `#236 <https://github.com/NiaOrg/NiaPy/pull/236>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

`2.0.0rc8 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc8>`__ (2019-11-11)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc7...2.0.0rc8>`__

**Merged pull requests:**

-  Fix pypi README `#235 <https://github.com/NiaOrg/NiaPy/pull/235>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

`2.0.0rc7 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc7>`__ (2019-11-11)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc6...2.0.0rc7>`__

**Merged pull requests:**

-  Fix bump2version `#234 <https://github.com/NiaOrg/NiaPy/pull/234>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

`2.0.0rc6 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc6>`__ (2019-11-11)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc5...2.0.0rc6>`__

**Closed issues:**

-  Confusion with GSO
   `#221 <https://github.com/NiaOrg/NiaPy/issues/221>`__
-  No module named ‘NiaPy.algorithms’
   `#219 <https://github.com/NiaOrg/NiaPy/issues/219>`__
-  Documentation fix
   `#211 <https://github.com/NiaOrg/NiaPy/issues/211>`__

**Merged pull requests:**

-  docs: add jhmenke as a contributor
   `#232 <https://github.com/NiaOrg/NiaPy/pull/232>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  replacing badges and mentions of appveyor and travis
   `#231 <https://github.com/NiaOrg/NiaPy/pull/231>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  cleanup old ci configurations
   `#230 <https://github.com/NiaOrg/NiaPy/pull/230>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  docs: add FlorianShepherd as a contributor
   `#229 <https://github.com/NiaOrg/NiaPy/pull/229>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  docs: add musawakiliML as a contributor
   `#228 <https://github.com/NiaOrg/NiaPy/pull/228>`__
   (`allcontributors[bot] <https://github.com/apps/allcontributors>`__)
-  Automatic Release `#226 <https://github.com/NiaOrg/NiaPy/pull/226>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fixes comments in runner.py
   `#225 <https://github.com/NiaOrg/NiaPy/pull/225>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix comment. replace mutation and crossover with uniform one.
   `#223 <https://github.com/NiaOrg/NiaPy/pull/223>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix runner nRuns issue
   `#222 <https://github.com/NiaOrg/NiaPy/pull/222>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  update run_jde.py `#217 <https://github.com/NiaOrg/NiaPy/pull/217>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  Added Cat Swarm Optimization algorithm
   `#216 <https://github.com/NiaOrg/NiaPy/pull/216>`__
   (`mihael-mika <https://github.com/mihael-mika>`__)
-  Bea algorithm `#214 <https://github.com/NiaOrg/NiaPy/pull/214>`__
   (`RokPot <https://github.com/RokPot>`__)

`2.0.0rc5 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc5>`__ (2019-05-06)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc4...2.0.0rc5>`__

**Implemented enhancements:**

-  Update Runner to accept an array of algorithm objects or strings
   `#189 <https://github.com/NiaOrg/NiaPy/issues/189>`__
-  Merging logging and printing task in StoppingTask
   `#208 <https://github.com/NiaOrg/NiaPy/pull/208>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Upgrade runner `#206 <https://github.com/NiaOrg/NiaPy/pull/206>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Foa fix `#199 <https://github.com/NiaOrg/NiaPy/pull/199>`__
   (`lukapecnik <https://github.com/lukapecnik>`__)
-  New examples (algorithm info + custom init population function)
   `#198 <https://github.com/NiaOrg/NiaPy/pull/198>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Dependencies, code style, etc.
   `#196 <https://github.com/NiaOrg/NiaPy/pull/196>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

**Fixed bugs:**

-  jDE runs without stopping
   `#201 <https://github.com/NiaOrg/NiaPy/issues/201>`__
-  Logger `#178 <https://github.com/NiaOrg/NiaPy/issues/178>`__

**Closed issues:**

-  Initial Update `#200 <https://github.com/NiaOrg/NiaPy/issues/200>`__
-  Port FSS algorithm to the new style
   `#167 <https://github.com/NiaOrg/NiaPy/issues/167>`__
-  Documentation improvements
   `#155 <https://github.com/NiaOrg/NiaPy/issues/155>`__

**Merged pull requests:**

-  Custom init pop example fix
   `#213 <https://github.com/NiaOrg/NiaPy/pull/213>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Fixed example and readme.md
   `#212 <https://github.com/NiaOrg/NiaPy/pull/212>`__
   (`bankojan <https://github.com/bankojan>`__)
-  minor fix in examples
   `#210 <https://github.com/NiaOrg/NiaPy/pull/210>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Removing ScalingTask & MoveTask
   `#209 <https://github.com/NiaOrg/NiaPy/pull/209>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  MBO algorithm implementation.
   `#207 <https://github.com/NiaOrg/NiaPy/pull/207>`__
   (`bankojan <https://github.com/bankojan>`__)
-  FOA tree aging and limitRepair bug fix.
   `#205 <https://github.com/NiaOrg/NiaPy/pull/205>`__
   (`lukapecnik <https://github.com/lukapecnik>`__)
-  Fixes `#203 <https://github.com/NiaOrg/NiaPy/pull/203>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  BA and HBA `#202 <https://github.com/NiaOrg/NiaPy/pull/202>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  More modified examples
   `#197 <https://github.com/NiaOrg/NiaPy/pull/197>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Example for custom benchmark
   `#195 <https://github.com/NiaOrg/NiaPy/pull/195>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Some changes in BA and HBA
   `#194 <https://github.com/NiaOrg/NiaPy/pull/194>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  significant commit of flower pollination algorithm
   `#193 <https://github.com/NiaOrg/NiaPy/pull/193>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  update of sigma calculation
   `#192 <https://github.com/NiaOrg/NiaPy/pull/192>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  PSO minor changes `#191 <https://github.com/NiaOrg/NiaPy/pull/191>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Simplified examples - part 2
   `#190 <https://github.com/NiaOrg/NiaPy/pull/190>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Simplified examples
   `#184 <https://github.com/NiaOrg/NiaPy/pull/184>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  New features. `#183 <https://github.com/NiaOrg/NiaPy/pull/183>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  FOA examples added and README.md update
   `#181 <https://github.com/NiaOrg/NiaPy/pull/181>`__
   (`lukapecnik <https://github.com/lukapecnik>`__)
-  FOA `#180 <https://github.com/NiaOrg/NiaPy/pull/180>`__
   (`lukapecnik <https://github.com/lukapecnik>`__)
-  add scandir dev dependency
   `#176 <https://github.com/NiaOrg/NiaPy/pull/176>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  New algorithms and port of old algorithms
   `#175 <https://github.com/NiaOrg/NiaPy/pull/175>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  fix scrutinizer python version
   `#174 <https://github.com/NiaOrg/NiaPy/pull/174>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  New tests `#173 <https://github.com/NiaOrg/NiaPy/pull/173>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)

`2.0.0rc4 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc4>`__ (2018-11-30)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc3...2.0.0rc4>`__

`2.0.0rc3 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc3>`__ (2018-11-30)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/1.0.2...2.0.0rc3>`__

**Closed issues:**

-  New mechanism for stopCond and old best values
   `#168 <https://github.com/NiaOrg/NiaPy/issues/168>`__
-  Coral Reefs Optimization Algorithm (CRO) and Anarchic society
   optimization (ASO)
   `#148 <https://github.com/NiaOrg/NiaPy/issues/148>`__

**Merged pull requests:**

-  Added iterations counter to some of the algorithms
   `#171 <https://github.com/NiaOrg/NiaPy/pull/171>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  Added fixes for stopping conditions
   `#170 <https://github.com/NiaOrg/NiaPy/pull/170>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  Added stopping conditions
   `#169 <https://github.com/NiaOrg/NiaPy/pull/169>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  Fish school search implementation in old format
   `#166 <https://github.com/NiaOrg/NiaPy/pull/166>`__
   (`tuahk <https://github.com/tuahk>`__)
-  update of comments: algorithm.py
   `#165 <https://github.com/NiaOrg/NiaPy/pull/165>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  New tests for MFO `#164 <https://github.com/NiaOrg/NiaPy/pull/164>`__
   (`firefly-cpp <https://github.com/firefly-cpp>`__)
-  Moth Flame Optimization
   `#163 <https://github.com/NiaOrg/NiaPy/pull/163>`__
   (`kivancguckiran <https://github.com/kivancguckiran>`__)
-  update conda build for version 1.0.2
   `#162 <https://github.com/NiaOrg/NiaPy/pull/162>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  add conda recipe `#160 <https://github.com/NiaOrg/NiaPy/pull/160>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  update comments `#159 <https://github.com/NiaOrg/NiaPy/pull/159>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  Fixes `#158 <https://github.com/NiaOrg/NiaPy/pull/158>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  HBA - bugfix `#157 <https://github.com/NiaOrg/NiaPy/pull/157>`__
   (`kivancguckiran <https://github.com/kivancguckiran>`__)

.. _section-2:

`1.0.2 <https://github.com/NiaOrg/NiaPy/tree/1.0.2>`__ (2018-10-24)
-------------------------------------------------------------------

`Full Changelog <https://github.com/NiaOrg/NiaPy/compare/2...1.0.2>`__

**Fixed bugs:**

-  Hybrid Bat Algorithm coding mistake?
   `#156 <https://github.com/NiaOrg/NiaPy/issues/156>`__

**Merged pull requests:**

-  fix Bat Algorithm `#161 <https://github.com/NiaOrg/NiaPy/pull/161>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

.. _section-3:

`2 <https://github.com/NiaOrg/NiaPy/tree/2>`__ (2018-08-30)
-----------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc2...2>`__

`2.0.0rc2 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc2>`__ (2018-08-30)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/2.0.0rc1...2.0.0rc2>`__

`2.0.0rc1 <https://github.com/NiaOrg/NiaPy/tree/2.0.0rc1>`__ (2018-08-30)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/1.0.1...2.0.0rc1>`__

**Fixed bugs:**

-  Differential evolution implementation
   `#135 <https://github.com/NiaOrg/NiaPy/issues/135>`__

**Closed issues:**

-  New feature: Support for maximization problems
   `#146 <https://github.com/NiaOrg/NiaPy/issues/146>`__
-  New algorithms `#145 <https://github.com/NiaOrg/NiaPy/issues/145>`__
-  Counting evaluations
   `#142 <https://github.com/NiaOrg/NiaPy/issues/142>`__
-  Convergence plots
   `#136 <https://github.com/NiaOrg/NiaPy/issues/136>`__

**Merged pull requests:**

-  fix rtd conf `#154 <https://github.com/NiaOrg/NiaPy/pull/154>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix rtd conf `#153 <https://github.com/NiaOrg/NiaPy/pull/153>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  add docs dependency
   `#152 <https://github.com/NiaOrg/NiaPy/pull/152>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Docs build fix `#151 <https://github.com/NiaOrg/NiaPy/pull/151>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fixes and new algorithm
   `#150 <https://github.com/NiaOrg/NiaPy/pull/150>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  New optimization algorithm and fixes for old ones
   `#149 <https://github.com/NiaOrg/NiaPy/pull/149>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  New features `#147 <https://github.com/NiaOrg/NiaPy/pull/147>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  Algorithm refactoring
   `#144 <https://github.com/NiaOrg/NiaPy/pull/144>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  New algorithms and benchmarks
   `#143 <https://github.com/NiaOrg/NiaPy/pull/143>`__
   (`kb2623 <https://github.com/kb2623>`__)
-  update `#141 <https://github.com/NiaOrg/NiaPy/pull/141>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  Update run_fa.py `#140 <https://github.com/NiaOrg/NiaPy/pull/140>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  Update run_abc.py `#139 <https://github.com/NiaOrg/NiaPy/pull/139>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  fix failing build `#138 <https://github.com/NiaOrg/NiaPy/pull/138>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fixed DE evaluations counter
   `#137 <https://github.com/NiaOrg/NiaPy/pull/137>`__
   (`mlaky88 <https://github.com/mlaky88>`__)
-  Fix renamed PyPI package
   `#134 <https://github.com/NiaOrg/NiaPy/pull/134>`__
   (`jacebrowning <https://github.com/jacebrowning>`__)
-  style fix `#133 <https://github.com/NiaOrg/NiaPy/pull/133>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  style fix `#132 <https://github.com/NiaOrg/NiaPy/pull/132>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  style fix `#131 <https://github.com/NiaOrg/NiaPy/pull/131>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  citing `#130 <https://github.com/NiaOrg/NiaPy/pull/130>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Zenodo added `#129 <https://github.com/NiaOrg/NiaPy/pull/129>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  DOI added `#128 <https://github.com/NiaOrg/NiaPy/pull/128>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)

.. _section-4:

`1.0.1 <https://github.com/NiaOrg/NiaPy/tree/1.0.1>`__ (2018-03-21)
-------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/1.0.0...1.0.1>`__

**Closed issues:**

-  [JOSS] Clarify target audience
   `#122 <https://github.com/NiaOrg/NiaPy/issues/122>`__
-  [JOSS] Comment on existing libraries/frameworks
   `#121 <https://github.com/NiaOrg/NiaPy/issues/121>`__
-  [JOSS] Better API Documentation
   `#120 <https://github.com/NiaOrg/NiaPy/issues/120>`__
-  [JOSS] Clarify set-up requirements in README and requirements.txt
   `#119 <https://github.com/NiaOrg/NiaPy/issues/119>`__
-  Testing the algorithms
   `#85 <https://github.com/NiaOrg/NiaPy/issues/85>`__
-  JOSS paper `#60 <https://github.com/NiaOrg/NiaPy/issues/60>`__

**Merged pull requests:**

-  fix `#127 <https://github.com/NiaOrg/NiaPy/pull/127>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  reference Fix `#126 <https://github.com/NiaOrg/NiaPy/pull/126>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Documentation added
   `#125 <https://github.com/NiaOrg/NiaPy/pull/125>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fix for issue #119
   `#124 <https://github.com/NiaOrg/NiaPy/pull/124>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  dois added `#118 <https://github.com/NiaOrg/NiaPy/pull/118>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fixes `#117 <https://github.com/NiaOrg/NiaPy/pull/117>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Fix paper title `#116 <https://github.com/NiaOrg/NiaPy/pull/116>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fix paper `#115 <https://github.com/NiaOrg/NiaPy/pull/115>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  arguments: Ts->integer; TournamentSelection: use shuffled indices in
   … `#114 <https://github.com/NiaOrg/NiaPy/pull/114>`__
   (`mlaky88 <https://github.com/mlaky88>`__)

.. _section-5:

`1.0.0 <https://github.com/NiaOrg/NiaPy/tree/1.0.0>`__ (2018-02-28)
-------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/1.0.0rc2...1.0.0>`__

**Merged pull requests:**

-  Runner export `#39 <https://github.com/NiaOrg/NiaPy/pull/39>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

`1.0.0rc2 <https://github.com/NiaOrg/NiaPy/tree/1.0.0rc2>`__ (2018-02-28)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/1.0.0rc1...1.0.0rc2>`__

`1.0.0rc1 <https://github.com/NiaOrg/NiaPy/tree/1.0.0rc1>`__ (2018-02-28)
-------------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/0.1.3a2...1.0.0rc1>`__

**Merged pull requests:**

-  fix algorithms docs
   `#113 <https://github.com/NiaOrg/NiaPy/pull/113>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  cleanup `#112 <https://github.com/NiaOrg/NiaPy/pull/112>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix README.rst `#111 <https://github.com/NiaOrg/NiaPy/pull/111>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  code style fixes `#110 <https://github.com/NiaOrg/NiaPy/pull/110>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  whitespace fix `#109 <https://github.com/NiaOrg/NiaPy/pull/109>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Pso algorithm `#108 <https://github.com/NiaOrg/NiaPy/pull/108>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  CS levy flight fix
   `#106 <https://github.com/NiaOrg/NiaPy/pull/106>`__
   (`mlaky88 <https://github.com/mlaky88>`__)
-  fix cs code style `#105 <https://github.com/NiaOrg/NiaPy/pull/105>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  CS fix `#103 <https://github.com/NiaOrg/NiaPy/pull/103>`__
   (`mlaky88 <https://github.com/mlaky88>`__)
-  Documentation `#102 <https://github.com/NiaOrg/NiaPy/pull/102>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Finishing runner `#101 <https://github.com/NiaOrg/NiaPy/pull/101>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)

`0.1.3a2 <https://github.com/NiaOrg/NiaPy/tree/0.1.3a2>`__ (2018-02-26)
-----------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/0.1.3a1...0.1.3a2>`__

`0.1.3a1 <https://github.com/NiaOrg/NiaPy/tree/0.1.3a1>`__ (2018-02-26)
-----------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/0.1.2a4...0.1.3a1>`__

`0.1.2a4 <https://github.com/NiaOrg/NiaPy/tree/0.1.2a4>`__ (2018-02-26)
-----------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/0.1.2a3...0.1.2a4>`__

`0.1.2a3 <https://github.com/NiaOrg/NiaPy/tree/0.1.2a3>`__ (2018-02-26)
-----------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/0.1.2a2...0.1.2a3>`__

.. _a2-2018-02-26-1:

`0.1.2a2 <https://github.com/NiaOrg/NiaPy/tree/0.1.2a2>`__ (2018-02-26)
-----------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/0.1.2a1...0.1.2a2>`__

**Merged pull requests:**

-  fix `#100 <https://github.com/NiaOrg/NiaPy/pull/100>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)

.. _a1-2018-02-26-1:

`0.1.2a1 <https://github.com/NiaOrg/NiaPy/tree/0.1.2a1>`__ (2018-02-26)
-----------------------------------------------------------------------

`Full
Changelog <https://github.com/NiaOrg/NiaPy/compare/cd5a1ff3e1c9f426fde8b40a625abc654c5434c2...0.1.2a1>`__

**Merged pull requests:**

-  version 0.1.2a1 `#99 <https://github.com/NiaOrg/NiaPy/pull/99>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  ga fix `#98 <https://github.com/NiaOrg/NiaPy/pull/98>`__
   (`mlaky88 <https://github.com/mlaky88>`__)
-  test fix `#97 <https://github.com/NiaOrg/NiaPy/pull/97>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fix docs `#96 <https://github.com/NiaOrg/NiaPy/pull/96>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  cs and pso fix `#95 <https://github.com/NiaOrg/NiaPy/pull/95>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  add getting started guide
   `#94 <https://github.com/NiaOrg/NiaPy/pull/94>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  algorithms docs fix `#93 <https://github.com/NiaOrg/NiaPy/pull/93>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  algorithms documentation fix
   `#92 <https://github.com/NiaOrg/NiaPy/pull/92>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  documentation fix `#91 <https://github.com/NiaOrg/NiaPy/pull/91>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Latex `#90 <https://github.com/NiaOrg/NiaPy/pull/90>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fixes docs building `#89 <https://github.com/NiaOrg/NiaPy/pull/89>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix code style `#88 <https://github.com/NiaOrg/NiaPy/pull/88>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  changes in DE & jDE `#87 <https://github.com/NiaOrg/NiaPy/pull/87>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  More changes in CS `#86 <https://github.com/NiaOrg/NiaPy/pull/86>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  Fixed some problems in CS
   `#84 <https://github.com/NiaOrg/NiaPy/pull/84>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  fix auto build docs `#83 <https://github.com/NiaOrg/NiaPy/pull/83>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix docs build `#82 <https://github.com/NiaOrg/NiaPy/pull/82>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Gen docs `#81 <https://github.com/NiaOrg/NiaPy/pull/81>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix indent `#80 <https://github.com/NiaOrg/NiaPy/pull/80>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  typo `#79 <https://github.com/NiaOrg/NiaPy/pull/79>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  new algorithms `#78 <https://github.com/NiaOrg/NiaPy/pull/78>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  NiaPy logo added `#77 <https://github.com/NiaOrg/NiaPy/pull/77>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fix codestyle `#76 <https://github.com/NiaOrg/NiaPy/pull/76>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fixing codestyle `#75 <https://github.com/NiaOrg/NiaPy/pull/75>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Fixed evals, added cuckoo search
   `#74 <https://github.com/NiaOrg/NiaPy/pull/74>`__
   (`mlaky88 <https://github.com/mlaky88>`__)
-  Refactoring `#73 <https://github.com/NiaOrg/NiaPy/pull/73>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  latex documentation fixes
   `#72 <https://github.com/NiaOrg/NiaPy/pull/72>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  benchmark tests added
   `#71 <https://github.com/NiaOrg/NiaPy/pull/71>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  tests added `#70 <https://github.com/NiaOrg/NiaPy/pull/70>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Gen docs `#69 <https://github.com/NiaOrg/NiaPy/pull/69>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  docs descriptions `#68 <https://github.com/NiaOrg/NiaPy/pull/68>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  prepare for docs `#67 <https://github.com/NiaOrg/NiaPy/pull/67>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fix issues `#66 <https://github.com/NiaOrg/NiaPy/pull/66>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Readthedocs configuration
   `#65 <https://github.com/NiaOrg/NiaPy/pull/65>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Cleanup docs and fix benchmark comments
   `#64 <https://github.com/NiaOrg/NiaPy/pull/64>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  docs generation `#63 <https://github.com/NiaOrg/NiaPy/pull/63>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Gen docs `#62 <https://github.com/NiaOrg/NiaPy/pull/62>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Generate docs `#61 <https://github.com/NiaOrg/NiaPy/pull/61>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  fix csendes benchmark
   `#59 <https://github.com/NiaOrg/NiaPy/pull/59>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  compatibility bugfixes
   `#58 <https://github.com/NiaOrg/NiaPy/pull/58>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Docs `#57 <https://github.com/NiaOrg/NiaPy/pull/57>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  add OS compatibillity fixes.
   `#56 <https://github.com/NiaOrg/NiaPy/pull/56>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Improved Docs `#55 <https://github.com/NiaOrg/NiaPy/pull/55>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Styblinski-Tang Function added
   `#54 <https://github.com/NiaOrg/NiaPy/pull/54>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Sum Squares added `#53 <https://github.com/NiaOrg/NiaPy/pull/53>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  decimal fixes `#52 <https://github.com/NiaOrg/NiaPy/pull/52>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Stepint function added
   `#51 <https://github.com/NiaOrg/NiaPy/pull/51>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Step function `#50 <https://github.com/NiaOrg/NiaPy/pull/50>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Schumer Steiglitz Function
   `#49 <https://github.com/NiaOrg/NiaPy/pull/49>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Salomon function `#48 <https://github.com/NiaOrg/NiaPy/pull/48>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Quintic function added
   `#47 <https://github.com/NiaOrg/NiaPy/pull/47>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Qing function added `#46 <https://github.com/NiaOrg/NiaPy/pull/46>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Pinter function added
   `#45 <https://github.com/NiaOrg/NiaPy/pull/45>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Csendes function `#44 <https://github.com/NiaOrg/NiaPy/pull/44>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Chung reynolds function
   `#43 <https://github.com/NiaOrg/NiaPy/pull/43>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Ridge function `#42 <https://github.com/NiaOrg/NiaPy/pull/42>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  fix latex export `#41 <https://github.com/NiaOrg/NiaPy/pull/41>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Happy cat function added
   `#40 <https://github.com/NiaOrg/NiaPy/pull/40>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  add comment of arguments for fpa.py
   `#38 <https://github.com/NiaOrg/NiaPy/pull/38>`__
   (`rhododendrom <https://github.com/rhododendrom>`__)
-  Move test `#37 <https://github.com/NiaOrg/NiaPy/pull/37>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  description added `#36 <https://github.com/NiaOrg/NiaPy/pull/36>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  Feature functions2 `#35 <https://github.com/NiaOrg/NiaPy/pull/35>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)
-  add runner export to xlsx
   `#34 <https://github.com/NiaOrg/NiaPy/pull/34>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Runner export `#33 <https://github.com/NiaOrg/NiaPy/pull/33>`__
   (`GregaVrbancic <https://github.com/GregaVrbancic>`__)
-  Feature functions2 `#32 <https://github.com/NiaOrg/NiaPy/pull/32>`__
   (`lucijabrezocnik <https://github.com/lucijabrezocnik>`__)

\* *This Changelog was automatically generated
by*\ `github_changelog_generator <https://github.com/github-changelog-generator/github-changelog-generator>`__
